Do lower gas prices mean happier consumers? | Pew Research Center
Description: Lower gasoline prices tend to improve consumer sentiment, but spending less at the pump doesn't mean people will spend more at the mall.
Keywords: economy,retail, gasoline,prices,consumers
Date: 20141216

Skip to Content

Numbers, Facts and Trends Shaping Your World

MenuProjects
Fact Tank - Our Lives in Numbers
December 16, 2014

# Do lower gasoline prices make for confident consumers?

By Drew DeSilver Leave a comment

Gasoline prices have been dropping since midsummer, and consumers’ confidence about the economy has been on the rise. Could there be a connection?

According to a new Pew Research Center report, 70% of Americans now report hearing mostly good news about gas prices, up from just 15% in August. In truth, gas prices have been falling for months: As of Monday, the national average price of a gallon of self-serve regular was $2.554 — $1.15 less than in late June (representing a nearly one-third drop), according to the U.S. Energy Information Administration. That’s the cheapest gas has been since October 2009. Also, Brent crude oil has fallen more than $45 a barrel since June and is now below $59 a barrel for the first time since May 2009.

Meanwhile, the University of Michigan’s Index of Consumer Sentiment stood at 88.8 in November, up 7 points since July and its highest reading since mid-2007. The preliminary December reading is even higher, at 93.8, though that’s still subject to revision.

We plotted the monthly consumer-sentiment index against the monthly average price of regular gas (adjusted for inflation) and found a moderately strong negative correlation — that is, consumer sentiment rose as pump prices fell. That aligns with previous research: For example, a 2012 paper from two researchers at Loyola University Maryland and the University of Maryland Baltimore County not only found an inverse correlation between gas prices and consumer sentiment, but used causality testing to conclude that price changes predicted sentiment changes and not the other way around.

A 2009 paper in the Journal of Monetary Economics, which also found a cause-and-effect relationship, analyzed the University of Michigan survey results in more detail to try to get at the dynamics of how consumers respond to energy-price changes. After a major one-time price jump, the researchers found, “an increasing number of people expect general business conditions and their personal financial situation to deteriorate over the coming year in response to an unanticipated loss in purchasing power….[T]he index for buying conditions for large household goods falls by 1.9 points. An even larger decrease is observed for vehicles….Increased pessimism about buying conditions in response to purchasing power losses is associated with expectations of higher unemployment, higher interest rates, and lower real family income.”

Those attitudinal changes have real-world consequences, though not large ones. The authors of the JME paper, Paul Edelstein and Lutz Kilian, concentrated mainly on unexpected increases, rather than drops, in energy prices; they estimated that a one-time, 1% increase in energy prices was associated with a 0.08% fall in total real consumption a year later, based on 1988-2006 data. But that was considerably less than the 0.30% decline seen in the 1970-1987 data; energy price shocks, they concluded, have less effect on the overall economy than they used to.

Edelstein and Kilian also estimated that one year after an unexpected, permanent increase of 25 cents a gallon in the price of gas, a typical household would have reduced its expenditures by $17 a month, with most of the adjustment coming in the first six months after the price increase. Concluded the researchers: “It takes repeated surprise increases in gasoline prices to generate large effects on household consumption, but over time the effects will add up.”

Topics: National Economy

Share the link:

1. Drew DeSilver is a Senior Writer at the Pew Research Center.

   - Posts
   - Email
   - @DrewDeSilver

Get Pew Research data by email

### Leave a Comment

Cancel Reply

Log In with Facebook

Sign In with Google

Or

Name Email (will not be published)
Current Year (YYYY)
Leave this field blank

All comments must follow the Pew Research comment policy and will be moderated before posting.

- Copyright 2014 Pew Research Center
- Terms & Conditions
- Privacy Policy
- Reprints, Permissions & Use Policy
- Feedback
- Careers
- Find an Expert